@@ -35,6 +35,8 @@
 #include "texmaker_popplerqt20/poppler-qt4.h"
 #elif defined(POPPLER22)
 #include "texmaker_popplerqt22/poppler-qt4.h"
+#elif defined(POPPLER24)
+#include <poppler-qt5.h>
 #else
 #include <poppler-qt4.h>
 #endif
@@ -85,6 +87,7 @@ fileLoaded=false;
 currentPage=1;
 
 doc = 0;
+searchleft=0.0; searchtop=0.0; searchright=0.0; searchbottom=0.0;
 scanner=NULL;
 path= QPainterPath();
 
@@ -760,7 +763,6 @@ connect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
 void PdfViewer::searchForwards(const QString &text)
 {
 int page = currentPage-1;
-
 while (page < doc->numPages()) 
   {
 
@@ -768,8 +770,12 @@ while (page < doc->numPages())
     {
     pdfview->clearPaths(currentPage-1);  
     }
-  if (doc->page(page)->search(text, searchLocation,Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
+  if (doc->page(page)->search(text, searchleft, searchtop, searchright, searchbottom, Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
     {
+    searchLocation.setLeft(searchleft);
+    searchLocation.setTop(searchtop);
+    searchLocation.setRight(searchright);
+    searchLocation.setBottom(searchbottom);
     if (!searchLocation.isNull()) 
       {
       path= QPainterPath();
@@ -795,8 +801,12 @@ while (page < currentPage-1)
     pdfview->clearPaths(currentPage-1);    
     }
   searchLocation = QRectF();
-  if (doc->page(page)->search(text, searchLocation,Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
+  if (doc->page(page)->search(text, searchleft, searchtop, searchright, searchbottom, Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
     {
+    searchLocation.setLeft(searchleft);
+    searchLocation.setTop(searchtop);
+    searchLocation.setRight(searchright);
+    searchLocation.setBottom(searchbottom);
     if (!searchLocation.isNull()) 
       {
       path= QPainterPath();
